# weco-deploy

[![Build Status](https://travis-ci.org/wellcomecollection/weco-deploy.svg?branch=master)](https://travis-ci.org/wellcomecollection/weco-deploy)

A tool for deploying ECS services at the Wellcome Collection.
